#
# spec file for package python-oslo.context
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without test
Name:           python-oslo.context
Version:        2.20.0
Release:        lp150.2.1
Summary:        OpenStack Oslo context library
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/oslo.context
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.context/oslo.context-2.20.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python2-pbr >= 2.0.0
BuildRequires:  python2-positional
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-positional
Requires:       python-debtcollector >= 1.2.0
Requires:       python-positional
BuildArch:      noarch
%if %{with test}
BuildRequires:  python2-debtcollector >= 1.2.0
BuildRequires:  python2-oslotest >= 3.2.0
BuildRequires:  python3-debtcollector >= 1.2.0
BuildRequires:  python3-oslotest >= 3.2.0
%endif
%python_subpackages

%description
The Oslo context library has helpers to maintain useful information
about a request context.
The request context is usually populated in the WSGI pipeline and
used by various modules such as logging.

%package -n python-oslo.context-doc
Summary:        Documentation for OpenStack common context library
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python-openstackdocstheme >= 1.18.1

%description -n python-oslo.context-doc
Documentation for the oslo-context library.

%prep
%autosetup -p1 -n oslo.context-2.20.0
%py_req_cleanup
# without git, openstackdocstheme has warnings which let the doc build fail
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
%{python_build}
# generate html docs
%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{python_install}

%if %{with test}
%check
%{python_expand rm -rf .testrepository
$python setup.py testr
}
%endif

%files %{python_files}
%license LICENSE
%doc README.rst
%{python2_sitelib}/oslo_context
%{python2_sitelib}/*.egg-info

%files -n python-oslo.context-doc
%license LICENSE
%doc doc/build/html

%changelog
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 2.20.0
  - Remove -U from pip install
  - Follow the new PTI for document build
  - Update reno for stable/pike
  - Remove use of positional decorator
  - Remove setting of version/release from releasenotes
  - Rename deprecated context params
  - Update the documentation link for doc migration
  - Revert "Postpone deprecation warnings to Pike"
  - Ouput a placeholder instead of the auth_token
  - Make from_dict extensible
  - add bandit to pep8 job
  - Output 'project' key in context's to_dict function
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 2.17.0
  - Provide unified calling interface for global_id
  - Fix URLs according to document migration
  - pbr.version.VersionInfo needs package name (oslo.xyz and not oslo_xyz)
  - Cleanup document formatting
  - rearrange the documentation to fit into the new standard layout
  - Postpone deprecation warnings to Pike
  - [Fix gate]Update test requirement
  - Add global_request_id to context
  - Update reno for stable/ocata
  - Remove pbr warnerrors in favor of sphinx check
  - Updated from global requirements
  - Switch from oslosphinx to openstackdocstheme
  - Optimize the link address
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 2.12.1:
  - Move existing attributes to _id suffixed attributes
  - Reformat the Context.__init__ arguments
  - Remove references to Python 3.4
  - Add Constraints support
  - Show team and repo badges on README
  - Update .gitreview for stable/ocata
  - Postpone deprecation warnings to Pike
  - Updated from global requirements
  - Add the service token details to context
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 2.11.0:
  - Update reno for stable/newton
  - Revert "Fix X-User and X-Tenant deprecated headers in from_environ"
  - Changed the home-page link
  - Fix typos
  - Enable release notes translation
  - Fix X-User and X-Tenant deprecated headers in from_environ
  - Updated from global requirements
  - Provide a way to deprecate policy values
* Thu Sep  1 2016 tbechtold@suse.com
- update to version 2.9.0
  * Emit deprecation warnings when positional args passed
  * Fix parameters of assertEqual are misplaced
  * Updated from global requirements
  * Manually specify from_dict parameters
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 2.8.0
  * Delete H803 in flake8 ignore list
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 2.7.0
  * Add Python 3.5 classifier and venv
  * Allow deprecated X-Tenant-Name in from_environ
* Fri Jul 29 2016 dmueller@suse.com
- update to 2.6.0:
  * Handle openstack.request_id in from_environ
  * Add is_admin_project to context
  * Updated from global requirements
  * Add reno for releasenotes management
  * Add oslo.context name attributes matching ids
* Mon Jul  4 2016 tbechtold@suse.com
- Update .spec from upstream via renderspec source service
* Tue Jun 14 2016 dmueller@suse.com
- update to 2.4.0:
  * Trivial: ignore openstack/common in flake8 exclude list
  * Strip roles in from_environ
  * Allow deprecated headers in from_environ
  * Drop babel as requirement since its not used
  * Updated from global requirements
  * Ensure to_dict() supports unicode
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Thu Mar  3 2016 tbechtold@suse.com
- Switch to .spec from rpm-packaging upstream project
* Fri Feb 26 2016 dmueller@suse.com
- update to 2.2.0:
  * Standardize an oslo.policy credentials dictionary
  * Revert "Add common oslo.log format parameters"
  * Add roles to context
  * Agnostic approach to construct context from_dict
  * Add common oslo.log format parameters
  * Improve Context docs with example syntax
  * Define method for oslo.log context parameters
  * Add additional unit tests
  * Fix request_id type on Python 3: use text (Unicode)
  * Updated from global requirements
  * Provide a helper to load a context from environment
  * Revert "Add properties for id attributes"
  * Add properties for id attributes
  * Trival: Remove 'MANIFEST.in'
  * Updated from global requirements
  * Remove python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Remove reference to undefined attributes
  * Fix coverage configuration and execution
  * Add shields.io version/downloads links/badges into README.rst
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
* Wed Sep  9 2015 tbechtold@suse.com
- update to 0.6.0:
  * Updated from global requirements
* Thu Aug 27 2015 tbechtold@suse.com
- update to 0.5.0:
  * Updated from global requirements
  * Add tox target to find missing requirements
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file
- Add -doc package
* Wed Jun  3 2015 dmueller@suse.com
- remove python-hacking dep
* Tue Jun  2 2015 tbechtold@suse.com
- update to 0.4.0:
  * Remove support for Python 3.3
  * Do not sync run_cross_tests.sh
  * Updated from global requirements
  * Uncap library requirements for liberty
  * Standardize setup.cfg summary for oslo libs
  * Update to latest hacking
  * Updated from global requirements
  * fix bug tracker link
- add _service file
* Tue Mar 10 2015 tbechtold@suse.com
- update to 0.2.0:
  * ensure we reset contexts when fixture is used
  * Activate pep8 check that _ is imported
* Wed Jan  7 2015 tbechtold@suse.com
- Initial packaging
